timeseries.SpaceCurve.plot — GDA Toolbox v1.0 Manual

# timeseries.SpaceCurve.plot

`SpaceCurve.` `plot`(canvas, title='SpaceCurve', color='blue')

  Plot the SpaceCurve in 3D.

  Parameters: | canvas : `matplotlib.axes._subplots.AxesSubplot` Be sure that 3D plotting is enabled on this canvas, with `mpl_toolkits.mplot3d import Axes3D` and `canvas = matplotlib.pyplot.subplot(projection='3d')` title : str A title for the figure. color : str The name of a color for the points to draw. Passed to the appropriate drawing library (bokeh or matplotlib).

  Notes

  Because we are using ECEF coordinates, the horizontal projection should be taken as an approximation!

#### Previous topic

timeseries.SpaceCurve.mass_profile

#### Next topic

timeseries.SpaceCurve.reparam